@@ -7,6 +7,7 @@ from ..general_operations.trigonometry import convert_radians_to_degrees
 
 # assigning magnet labels based on type
 def assign_magnet_labels(magnet, index1):
+
     # adding labels for rectangular magnet
     if magnet.__class__.__name__ == 'rectangular_magnet':
         magnet.magnet_label = 'R%02d' % (index1)
@@ -14,26 +15,27 @@ def assign_magnet_labels(magnet, index1):
 
     # adding labels for circular magnet
     elif magnet.__class__.__name__ == 'circular_magnet':
-        if magnet.rads < 0.396:
+        if magnet.rads < 92.71721:
             magnet.magnet_label = 'Blu'
-        elif 0.396 <= magnet.rads < 0.627:
+        elif 0.396 <= magnet.rads < 147.91658:
             magnet.magnet_label = 'Gre'
-        elif 0.627 <= magnet.rads < 0.823:
+        elif 0.627 <= magnet.rads < 196.05124:
             magnet.magnet_label = 'Yel'
-        elif magnet.rads >= 0.823:
+        elif magnet.rads >= 196.05124:
             magnet.magnet_label = 'Mag'
 
     return magnet, index1
 
 
 # flagging unresolvable conflicts by recording them in file and assigning '0' placement order to them
-def check_for_unresolvable_conflict(magnet, conflictFile, max_order, clusterNum, tileNum):
+def check_for_unresolvable_conflict(magnet, conflictFile, max_order, clusterNum, tileName):
+
     # placement index checking and assigning placement order accordingly
     if magnet.placement_index == None:
         order = 0
         with open(conflictFile, 'a') as fp:
             conflict = magnet.__class__.__name__ + ' ' + str(int(magnet.index)) + ' is an unresolvable conflict,' + \
-                       ' detected in Cluster ' + str(clusterNum) + ', tile ' + str(tileNum) + '\n'
+                       ' detected in Cluster ' + str(clusterNum) + ', tile ' + str(tileName) + '\n'
             fp.write(conflict)
 
     else:
@@ -47,6 +49,7 @@ def check_for_unresolvable_conflict(magnet, conflictFile, max_order, clusterNum,
 
 # when having more than 1 placement orders, the magnets with 1st placement order are to be assigned any pickup direction
 def add_pickupDirection(magnet, available_pickup):
+
     # magnets with placement order of 1 are placed at first so can be placed from any pickup direction
     if available_pickup == []:
         if magnet.__class__.__name__ == 'circular_magnet':
@@ -84,6 +87,8 @@ def assign_preferable_pickupDirection(available_pickup):
 
 # angles required by the robotic arm to pick up and then put down the magnet in correct position
 def calculate_pickup_putdown_angles(magnet, available_pickup):
+
+    #import ipdb; ipdb.set_trace()
     azAngs = convert_radians_to_degrees(magnet.azAngs)
 
     # rotation for pickup and putdown of circular magnets
@@ -116,7 +121,9 @@ def calculate_pickup_putdown_angles(magnet, available_pickup):
     # rotation for pickup and putdown of rectangular magnets
     elif magnet.__class__.__name__ == 'rectangular_magnet':
         magnet.rotation_pickup = 180
+
         ang_azAngs = convert_radians_to_degrees(magnet.rectangular_magnet_input_orientation) + 270
+        #import ipdb; ipdb.set_trace()
         if ang_azAngs < 180 and azAngs < 90:
             magnet.rotation_putdown = (90 - azAngs) + (180 - ang_azAngs)
             if 'I' in available_pickup:
@@ -133,17 +140,17 @@ def calculate_pickup_putdown_angles(magnet, available_pickup):
             magnet.rotation_putdown = (450 - azAngs) + (180 - ang_azAngs)
             if 'I' in available_pickup:
                 magnet.rotation_putdown = magnet.rotation_putdown - 180
-
+    #print(magnet.rotation_putdown)
     return magnet
 
 
 # checking angle to make sure it is within the range of 0 to 360
 def check_for_negative_twopi_angle(angle):
 
-    if angle < 0:
-        angle = 360 + angle
-    elif angle > 360:
-        angle = angle - 360
+    # if angle < 0:
+    #     angle = 360 + angle
+    # elif angle > 360:
+    #     angle = angle - 360
 
-    return angle
+    return angle % 360
 
